@@ -380,10 +380,8 @@ static void create_win( int argc, char **argv )
   XWMHints	wmhints;
   XTextProperty name;
 
-/*
   if ( xcin_row == 1 )
      sizehints.height /= 2;
-*/
 
   main_win = XCreateSimpleWindow( display, DefaultRootWindow( display ),
 				  sizehints.x,		sizehints.y,
@@ -1058,25 +1056,19 @@ static void show_halffull( void )
 
 void switch_active_client( InmdState *state, Window cli_win )
 {
-  int refresh = 1;
   last_win = cli_win;
 
   if ( ignore_cli_stat )
 	ignore_cli_stat = 0;
-  else 
+  else
      if ( state->_CurInMethod )
-       if(memcmp(&inmdstate, state, sizeof( inmdstate)))
-               memcpy( &inmdstate, state, sizeof( inmdstate ) );
-       else                                                     
-               refresh = 0;
+	memcpy( &inmdstate, state, sizeof( inmdstate ) );
 
   if ( hide_xcin && ( EngChi || HalfFull ) )
      Show_Xcin();
   else if ( hide_xcin && !EngChi && !HalfFull )
      XUnmapWindow( display, main_win );
 
-  if(!refresh)
-       return;
   gotoxy( 0, MROW - 1 );
 
   ClrShowArea( 0 );
@@ -1532,7 +1524,7 @@ void main(int argc, char **argv)
     char *d_name;
 
     puts("\n"
-         "+------------- XCIN version 2.3.04 ------------+\n"
+         "+------------- XCIN version 2.3.03 ------------+\n"
 	 "|                                              |\n"
          "|   by Edward Der-Hua Liu, Taiwan              |\n"
 	 "|                                              |\n"
@@ -1671,12 +1663,12 @@ void PrintHelpMessage(char *arg)
 "     -font       Ascii font name.\n"
 "     -fnb5       Big5 font name.\n"
 "     -display    display name.\n"
-"     -in1        in method 1 (e.g. cj.tab).\n"
+"     -in1        in method 1 (eg) cj.tab.\n"
 "     -in2        in method 2.\n"
 "     -in4        in method 4.\n"
 "     -in5        in method 5.\n"
 "     -in7        in method 7.\n"
-"     -in8        in method 8 (e.g. array30.tab).\n"
+"     -in8        in method 8 (eg) ar30.tab.\n"
 "     -in9        in method 9.\n"
 "     -vocbox     vocabulary box file name.\n"
 "     -in12       in method 12.\n"
